@@ -14,7 +14,6 @@ import aiohttp
 from aiohttp.client_reqrep import ClientRequest, ClientResponse, Fingerprint
 from aiohttp.connector import _SSL_CONTEXT_VERIFIED
 from aiohttp.helpers import TimerNoop
-from aiohttp.test_utils import make_mocked_coro
 
 pytestmark = pytest.mark.skipif(
     sys.platform == "win32", reason="Proxy tests are unstable on Windows"
@@ -27,7 +26,9 @@ class TestProxy(unittest.TestCase):
     }
     mocked_response = mock.Mock(**response_mock_attrs)
     clientrequest_mock_attrs = {
-        "return_value.send.return_value.start": make_mocked_coro(mocked_response),
+        "return_value.send.return_value.start": mock.AsyncMock(
+            return_value=mocked_response
+        ),
     }
 
     def setUp(self):
@@ -61,8 +62,8 @@ class TestProxy(unittest.TestCase):
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -79,7 +80,9 @@ class TestProxy(unittest.TestCase):
                 "transport.get_extra_info.return_value": False,
             }
         )
-        self.loop.create_connection = make_mocked_coro((proto.transport, proto))
+        self.loop.create_connection = mock.AsyncMock(
+            return_value=(proto.transport, proto)
+        )
         conn = self.loop.run_until_complete(
             connector.connect(req, None, aiohttp.ClientTimeout())
         )
@@ -119,8 +122,8 @@ class TestProxy(unittest.TestCase):
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -137,7 +140,9 @@ class TestProxy(unittest.TestCase):
                 "transport.get_extra_info.return_value": False,
             }
         )
-        self.loop.create_connection = make_mocked_coro((proto.transport, proto))
+        self.loop.create_connection = mock.AsyncMock(
+            return_value=(proto.transport, proto)
+        )
         conn = self.loop.run_until_complete(
             connector.connect(req, None, aiohttp.ClientTimeout())
         )
@@ -185,8 +190,8 @@ class TestProxy(unittest.TestCase):
             return aiohttp.TCPConnector()
 
         connector: aiohttp.TCPConnector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            raise_exception=OSError("dont take it serious")
+        connector._resolve_host = mock.AsyncMock(
+            side_effect=OSError("dont take it serious")
         )
 
         req = ClientRequest(
@@ -207,14 +212,15 @@ class TestProxy(unittest.TestCase):
         "aiohttp.connector.aiohappyeyeballs.start_connection",
         autospec=True,
         spec_set=True,
+        return_value=mock.create_autospec(socket.socket, spec_set=True, instance=True),
     )
     def test_proxy_connection_error(self, start_connection: Any) -> None:
         async def make_conn():
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "www.python.org",
                     "host": "127.0.0.1",
@@ -225,8 +231,8 @@ class TestProxy(unittest.TestCase):
                 }
             ]
         )
-        connector._loop.create_connection = make_mocked_coro(
-            raise_exception=OSError("dont take it serious")
+        connector._loop.create_connection = mock.AsyncMock(
+            side_effect=OSError("dont take it serious")
         )
 
         req = ClientRequest(
@@ -265,15 +271,15 @@ class TestProxy(unittest.TestCase):
             loop=self.loop,
             session=mock.Mock(),
         )
-        proxy_req.send = make_mocked_coro(proxy_resp)
-        proxy_resp.start = make_mocked_coro(mock.Mock(status=200))
+        proxy_req.send = mock.AsyncMock(return_value=proxy_resp)
+        proxy_resp.start = mock.AsyncMock(return_value=mock.Mock(status=200))
 
         async def make_conn():
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -286,8 +292,8 @@ class TestProxy(unittest.TestCase):
         )
 
         tr, proto = mock.Mock(), mock.Mock()
-        self.loop.create_connection = make_mocked_coro((tr, proto))
-        self.loop.start_tls = make_mocked_coro(mock.Mock())
+        self.loop.create_connection = mock.AsyncMock(return_value=(tr, proto))
+        self.loop.start_tls = mock.AsyncMock(return_value=mock.Mock())
 
         req = ClientRequest(
             "GET",
@@ -334,15 +340,15 @@ class TestProxy(unittest.TestCase):
             loop=self.loop,
             session=mock.Mock(),
         )
-        proxy_req.send = make_mocked_coro(proxy_resp)
-        proxy_resp.start = make_mocked_coro(mock.Mock(status=200))
+        proxy_req.send = mock.AsyncMock(return_value=proxy_resp)
+        proxy_resp.start = mock.AsyncMock(return_value=mock.Mock(status=200))
 
         async def make_conn():
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -355,8 +361,8 @@ class TestProxy(unittest.TestCase):
         )
 
         tr, proto = mock.Mock(), mock.Mock()
-        self.loop.create_connection = make_mocked_coro((tr, proto))
-        self.loop.start_tls = make_mocked_coro(mock.Mock())
+        self.loop.create_connection = mock.AsyncMock(return_value=(tr, proto))
+        self.loop.start_tls = mock.AsyncMock(return_value=mock.Mock())
 
         req = ClientRequest(
             "GET",
@@ -417,18 +423,21 @@ class TestProxy(unittest.TestCase):
                 fingerprint_mock.check.side_effect = aiohttp.ServerFingerprintMismatch(
                     b"exp", b"got", "example.com", 8080
                 )
-                with mock.patch.object(
-                    proxy_req,
-                    "send",
-                    autospec=True,
-                    spec_set=True,
-                    return_value=proxy_resp,
-                ), mock.patch.object(
-                    proxy_resp,
-                    "start",
-                    autospec=True,
-                    spec_set=True,
-                    return_value=mock.Mock(status=200),
+                with (
+                    mock.patch.object(
+                        proxy_req,
+                        "send",
+                        autospec=True,
+                        spec_set=True,
+                        return_value=proxy_resp,
+                    ),
+                    mock.patch.object(
+                        proxy_resp,
+                        "start",
+                        autospec=True,
+                        spec_set=True,
+                        return_value=mock.Mock(status=200),
+                    ),
                 ):
                     connector = self.loop.run_until_complete(make_conn())
                     host = [
@@ -441,30 +450,35 @@ class TestProxy(unittest.TestCase):
                             "flags": 0,
                         }
                     ]
-                    with mock.patch.object(
-                        connector,
-                        "_resolve_host",
-                        autospec=True,
-                        spec_set=True,
-                        return_value=host,
-                    ), mock.patch.object(
-                        connector,
-                        "_get_fingerprint",
-                        autospec=True,
-                        spec_set=True,
-                        return_value=fingerprint_mock,
-                    ), mock.patch.object(  # Called on connection to http://proxy.example.com
-                        self.loop,
-                        "create_connection",
-                        autospec=True,
-                        spec_set=True,
-                        return_value=(mock.Mock(), mock.Mock()),
-                    ), mock.patch.object(  # Called on connection to https://www.python.org
-                        self.loop,
-                        "start_tls",
-                        autospec=True,
-                        spec_set=True,
-                        return_value=TransportMock(),
+                    with (
+                        mock.patch.object(
+                            connector,
+                            "_resolve_host",
+                            autospec=True,
+                            spec_set=True,
+                            return_value=host,
+                        ),
+                        mock.patch.object(
+                            connector,
+                            "_get_fingerprint",
+                            autospec=True,
+                            spec_set=True,
+                            return_value=fingerprint_mock,
+                        ),
+                        mock.patch.object(  # Called on connection to http://proxy.example.com
+                            self.loop,
+                            "create_connection",
+                            autospec=True,
+                            spec_set=True,
+                            return_value=(mock.Mock(), mock.Mock()),
+                        ),
+                        mock.patch.object(  # Called on connection to https://www.python.org
+                            self.loop,
+                            "start_tls",
+                            autospec=True,
+                            spec_set=True,
+                            return_value=TransportMock(),
+                        ),
                     ):
                         req = ClientRequest(
                             "GET",
@@ -504,15 +518,15 @@ class TestProxy(unittest.TestCase):
             loop=self.loop,
             session=mock.Mock(),
         )
-        proxy_req.send = make_mocked_coro(proxy_resp)
-        proxy_resp.start = make_mocked_coro(mock.Mock(status=200))
+        proxy_req.send = mock.AsyncMock(return_value=proxy_resp)
+        proxy_resp.start = mock.AsyncMock(return_value=mock.Mock(status=200))
 
         async def make_conn():
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -525,8 +539,8 @@ class TestProxy(unittest.TestCase):
         )
 
         tr, proto = mock.Mock(), mock.Mock()
-        self.loop.create_connection = make_mocked_coro((tr, proto))
-        self.loop.start_tls = make_mocked_coro(mock.Mock())
+        self.loop.create_connection = mock.AsyncMock(return_value=(tr, proto))
+        self.loop.start_tls = mock.AsyncMock(return_value=mock.Mock())
 
         req = ClientRequest(
             "GET",
@@ -571,15 +585,15 @@ class TestProxy(unittest.TestCase):
             loop=self.loop,
             session=mock.Mock(),
         )
-        proxy_req.send = make_mocked_coro(proxy_resp)
-        proxy_resp.start = make_mocked_coro(mock.Mock(status=200))
+        proxy_req.send = mock.AsyncMock(return_value=proxy_resp)
+        proxy_resp.start = mock.AsyncMock(return_value=mock.Mock(status=200))
 
         async def make_conn():
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -592,9 +606,11 @@ class TestProxy(unittest.TestCase):
         )
 
         # Called on connection to http://proxy.example.com
-        self.loop.create_connection = make_mocked_coro((mock.Mock(), mock.Mock()))
+        self.loop.create_connection = mock.AsyncMock(
+            return_value=(mock.Mock(), mock.Mock())
+        )
         # Called on connection to https://www.python.org
-        self.loop.start_tls = make_mocked_coro(raise_exception=ssl.CertificateError)
+        self.loop.start_tls = mock.AsyncMock(side_effect=ssl.CertificateError)
 
         req = ClientRequest(
             "GET",
@@ -632,15 +648,15 @@ class TestProxy(unittest.TestCase):
             loop=self.loop,
             session=mock.Mock(),
         )
-        proxy_req.send = make_mocked_coro(proxy_resp)
-        proxy_resp.start = make_mocked_coro(mock.Mock(status=200))
+        proxy_req.send = mock.AsyncMock(return_value=proxy_resp)
+        proxy_resp.start = mock.AsyncMock(return_value=mock.Mock(status=200))
 
         async def make_conn():
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -653,11 +669,11 @@ class TestProxy(unittest.TestCase):
         )
 
         # Called on connection to http://proxy.example.com
-        self.loop.create_connection = make_mocked_coro(
-            (mock.Mock(), mock.Mock()),
+        self.loop.create_connection = mock.AsyncMock(
+            return_value=(mock.Mock(), mock.Mock()),
         )
         # Called on connection to https://www.python.org
-        self.loop.start_tls = make_mocked_coro(raise_exception=ssl.SSLError)
+        self.loop.start_tls = mock.AsyncMock(side_effect=ssl.SSLError)
 
         req = ClientRequest(
             "GET",
@@ -695,15 +711,17 @@ class TestProxy(unittest.TestCase):
             loop=self.loop,
             session=mock.Mock(),
         )
-        proxy_req.send = make_mocked_coro(proxy_resp)
-        proxy_resp.start = make_mocked_coro(mock.Mock(status=400, reason="bad request"))
+        proxy_req.send = mock.AsyncMock(return_value=proxy_resp)
+        proxy_resp.start = mock.AsyncMock(
+            return_value=mock.Mock(status=400, reason="bad request")
+        )
 
         async def make_conn():
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -717,7 +735,7 @@ class TestProxy(unittest.TestCase):
 
         tr, proto = mock.Mock(), mock.Mock()
         tr.get_extra_info.return_value = None
-        self.loop.create_connection = make_mocked_coro((tr, proto))
+        self.loop.create_connection = mock.AsyncMock(return_value=(tr, proto))
 
         req = ClientRequest(
             "GET",
@@ -761,15 +779,15 @@ class TestProxy(unittest.TestCase):
             loop=self.loop,
             session=mock.Mock(),
         )
-        proxy_req.send = make_mocked_coro(proxy_resp)
-        proxy_resp.start = make_mocked_coro(raise_exception=OSError("error message"))
+        proxy_req.send = mock.AsyncMock(return_value=proxy_resp)
+        proxy_resp.start = mock.AsyncMock(side_effect=OSError("error message"))
 
         async def make_conn():
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -783,7 +801,7 @@ class TestProxy(unittest.TestCase):
 
         tr, proto = mock.Mock(), mock.Mock()
         tr.get_extra_info.return_value = None
-        self.loop.create_connection = make_mocked_coro((tr, proto))
+        self.loop.create_connection = mock.AsyncMock(return_value=(tr, proto))
 
         req = ClientRequest(
             "GET",
@@ -812,8 +830,8 @@ class TestProxy(unittest.TestCase):
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -827,7 +845,7 @@ class TestProxy(unittest.TestCase):
 
         tr, proto = mock.Mock(), mock.Mock()
         tr.get_extra_info.return_value = None
-        self.loop.create_connection = make_mocked_coro((tr, proto))
+        self.loop.create_connection = mock.AsyncMock(return_value=(tr, proto))
 
         req = ClientRequest(
             "GET",
@@ -884,15 +902,15 @@ class TestProxy(unittest.TestCase):
             loop=self.loop,
             session=mock.Mock(),
         )
-        proxy_req.send = make_mocked_coro(proxy_resp)
-        proxy_resp.start = make_mocked_coro(mock.Mock(status=200))
+        proxy_req.send = mock.AsyncMock(return_value=proxy_resp)
+        proxy_resp.start = mock.AsyncMock(return_value=mock.Mock(status=200))
 
         async def make_conn():
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -905,8 +923,8 @@ class TestProxy(unittest.TestCase):
         )
 
         tr, proto = mock.Mock(), mock.Mock()
-        self.loop.create_connection = make_mocked_coro((tr, proto))
-        self.loop.start_tls = make_mocked_coro(mock.Mock())
+        self.loop.create_connection = mock.AsyncMock(return_value=(tr, proto))
+        self.loop.start_tls = mock.AsyncMock(return_value=mock.Mock())
 
         req = ClientRequest(
             "GET",
@@ -918,13 +936,23 @@ class TestProxy(unittest.TestCase):
             connector._create_connection(req, None, aiohttp.ClientTimeout())
         )
 
-        self.loop.start_tls.assert_called_with(
-            mock.ANY,
-            mock.ANY,
-            _SSL_CONTEXT_VERIFIED,
-            server_hostname="www.python.org",
-            ssl_handshake_timeout=mock.ANY,
-        )
+        if sys.version_info >= (3, 11):
+            self.loop.start_tls.assert_called_with(
+                mock.ANY,
+                mock.ANY,
+                _SSL_CONTEXT_VERIFIED,
+                server_hostname="www.python.org",
+                ssl_handshake_timeout=mock.ANY,
+                ssl_shutdown_timeout=0.1,
+            )
+        else:
+            self.loop.start_tls.assert_called_with(
+                mock.ANY,
+                mock.ANY,
+                _SSL_CONTEXT_VERIFIED,
+                server_hostname="www.python.org",
+                ssl_handshake_timeout=mock.ANY,
+            )
 
         self.assertEqual(req.url.path, "/")
         self.assertEqual(proxy_req.method, "CONNECT")
@@ -960,15 +988,15 @@ class TestProxy(unittest.TestCase):
             loop=self.loop,
             session=mock.Mock(),
         )
-        proxy_req.send = make_mocked_coro(proxy_resp)
-        proxy_resp.start = make_mocked_coro(mock.Mock(status=200))
+        proxy_req.send = mock.AsyncMock(return_value=proxy_resp)
+        proxy_resp.start = mock.AsyncMock(return_value=mock.Mock(status=200))
 
         async def make_conn():
             return aiohttp.TCPConnector()
 
         connector = self.loop.run_until_complete(make_conn())
-        connector._resolve_host = make_mocked_coro(
-            [
+        connector._resolve_host = mock.AsyncMock(
+            return_value=[
                 {
                     "hostname": "hostname",
                     "host": "127.0.0.1",
@@ -981,8 +1009,8 @@ class TestProxy(unittest.TestCase):
         )
 
         tr, proto = mock.Mock(), mock.Mock()
-        self.loop.create_connection = make_mocked_coro((tr, proto))
-        self.loop.start_tls = make_mocked_coro(mock.Mock())
+        self.loop.create_connection = mock.AsyncMock(return_value=(tr, proto))
+        self.loop.start_tls = mock.AsyncMock(return_value=mock.Mock())
 
         self.assertIn("AUTHORIZATION", proxy_req.headers)
         self.assertNotIn("PROXY-AUTHORIZATION", proxy_req.headers)
